require 'spec_helper'
require 'grid/node'
require 'grid/zmq/client'

module Grid
  describe Node do
    it 'can register and get the command invoked on fake stdin' do
      executed = 'old'
      
      node = Node.new
      node.command :foo do |params|
        executed = params['value']
      end

      stdin = FakeStdin.new

      node.listen(stdin, nil)
      
      stdin.send(:foo, 'value' => 'new')

      executed.should == 'new'
    end  

    it 'can register and get the command invoked on zeromq stdin' do
      address = 'tcp://127.0.0.1:2222'
      executed = 'old'
      
      node = Node.new
      node.command :foo do |params|        
        executed = params['value']

        Thread.current.kill
      end

      client = Grid::ZMQ::Client.new(address)
      thread = Thread.new { 
        stdin = ZMQ::Stdin.new
        node.listen(stdin, address) 
      }

      sleep 0.1

      client.call(:foo, :value => 'new')

      thread.join

      executed.should == 'new'
    end  
  end
end